"""
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
P3D script : ShaperColorByLayer
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Script Target : 
|~----------------------------------------------------------------------------~|

 This script affects : shaper colors / geometry layers

|~----------------------------------------------------------------------------~|

Compatible Versions : 
|~----------------------------------------------------------------------------~|

 This script is compatible with versions : 2022.0
 
|~----------------------------------------------------------------------------~|


Requirements : 
|~----------------------------------------------------------------------------~|

 Must have .P3D project (CurrentP3DSession)

 Special conditions : None

|~----------------------------------------------------------------------------~|



Description :
|~----------------------------------------------------------------------------~|

 This script will assign a color to each layer.
 All surfaces contained in a layer will have the same color.     

|~----------------------------------------------------------------------------~|


Usage:
|~----------------------------------------------------------------------------~|
 
 Classic use case in P3D :  Scripting/Execute Script -> choose script

|~----------------------------------------------------------------------------~|

Data output format :
|~----------------------------------------------------------------------------~|

 A console message will be presented indicating that the shaper colors have been changed.

|~----------------------------------------------------------------------------~|

"""


import random

from p3dsdk import ColorRgb, CurrentP3DSession, Surface, SceneObject, P3DFile, GeometryLayer


def random_value():
    return random.uniform(0.0, 1.0)


def random_rgb() -> ColorRgb:
    return ColorRgb(random_value(), random_value(), random_value())


def set_random_color_to_surfaces(geometry_layer_list: [GeometryLayer]):
    for layer in geometry_layer_list:
        surfaces = layer.list_surfaces()
        layer_random_color = random_rgb()
        for surface in surfaces:
            surface.color = layer_random_color


with CurrentP3DSession(33900) as p3d:
    model = p3d.data.list_models()[0]  # get first model
    layers = model.list_geometry_layers(recursive=True)  # get all layers in model
    set_random_color_to_surfaces(layers)
    print("Each layer is now represented by a color.")
